@@ -16,7 +16,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -263,10 +263,11 @@ static int oss_dsp_hw_params(oss_dsp_t *dsp)
 			if (err < 0)
 				return err;
 			periods_min = 2;
-			err = snd_pcm_hw_params_set_periods_min(pcm, hw, &periods_min, 0);
-			if (err < 0)
-				return err;
-			if (dsp->maxfrags > 0) {
+			if (!dsp->maxfrags) {
+				err = snd_pcm_hw_params_set_periods_min(pcm, hw, &periods_min, 0);
+				if (err < 0)
+					return err;
+			} else {
 				unsigned int periods_max = periods_min > dsp->maxfrags
 					? periods_min : dsp->maxfrags;
 				err = snd_pcm_hw_params_set_periods_max(pcm, hw,
@@ -308,8 +309,8 @@ static int oss_dsp_hw_params(oss_dsp_t *dsp)
 		if (err < 0)
 			return err;
 #if 0
-		if (alsa_oss_debug)
-			snd_pcm_dump_setup(pcm, stderr);
+		if (alsa_oss_debug && alsa_oss_debug_out)
+			snd_pcm_dump_setup(pcm, alsa_oss_debug_out);
 #endif
 		if (err < 0)
 			return err;
